#
# Render::ResumeHTML -- Render in "pretty resume" HTML
#
# Copyright (c) 2002, 2003 Brian Katzung, Kappa Computer Solutions, LLC.
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# For more information, contact:
#
#	Kappa Computer Solutions, LLC
#	3223 Lake Ave #15C-393
#	Wilmette, IL 60091-1074
#	877.367.8837 (US) or 781.370.1093
#	http://www.kappacs.com/
#
# 1992-09-25	Created by Brian Katzung.
#

package Render::ResumeHTML;

use strict;
use Parse::XMLLite qw(dispatch);
use Render::HTML;
use vars qw(@ISA);

@ISA = qw(Render::HTML);

#----------------------------------------------------------------------
# Format tree (private instance method)

sub _format
{
	my ($self, $node) = @_;

	return if (dispatch($node,
	'b-tag' => { 'h1' => sub { $self->_format_H1($node); }, },
	'e-tag' => { 'h1' => sub { ; }, },
	));

	$self->SUPER::_format($node);
}

#----------------------------------------------------------------------
# Format H1 node (private instance method)

sub _format_H1
{
	my ($self, $node) = @_;
	my $type = $node->{'type'};

	print $self->{'table_spacer'} if ($self->{'did_table'});
	print "<TABLE border='0' cellpadding='0' cellspacing='0'>\n",
	  "<TR><TD><H1>";
	$self->_format_content($node);
	print "</H1></TD></TR></TABLE>";
	++$self->{'did_table'};
}

#----------------------------------------------------------------------
# Generate the HTML HEAD section (private instance method)

sub _render_head
{
	my ($self) = @_;

	return if ($self->{'did_head'});

	print <<EOT;
<HTML>
<HEAD>
<TITLE>$self->{'title'}</TITLE>
<STYLE>
H1 {
	color: #000099;
	border-style: solid;
	border-color: #666666;
	border-width: 0 0 2px 0;
	line-height: 100%;
	margin-bottom: 0;
	padding-bottom: 0;
}
TABLE H2 {
	color: #000099;
	margin-bottom: 0;
}
H2 {
	color: #000099;
}
TABLE H3 {
	margin-bottom: 0;
}
STRONG {
	font-weight: bold;
	text-decoration: underline;
}
</STYLE>
</HEAD>
<BODY bgcolor='#FFFFFF'>
EOT

	++$self->{'did_head'};
}

1;
