#
# Render::ResumeWordHTML --
#	Render in "pretty resume" HTML for import into MS Word
#
# Copyright (c) 2002 Brian Katzung, Kappa Computer Solutions, LLC.
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# For more information, contact:
#
#	Kappa Computer Solutions, LLC
#	3223 Lake Ave #15C-393
#	Wilmette, IL 60091-1074
#	877.367.8837 (US) or 781.370.1093
#	http://www.kappacs.com/
#
# 2002-09-26	Created by Brian Katzung.
#

package Render::ResumeWordHTML;

use strict;
use Parse::XMLLite qw(dispatch);
use Render::ResumeHTML;
use vars qw(@ISA);

@ISA = qw(Render::ResumeHTML);

#----------------------------------------------------------------------
# Format a node (private instance method)

sub _format
{
	my ($self, $node) = @_;

	return if (dispatch($node,
	'b-tag' =>
	{
		'h1' => sub { $self->Render::HTML::_format($node); },
		'li' => sub { $self->_format_LI($node); },
	},
	'e-tag' => { 'h1' => sub { $self->Render::HTML::_format($node); }, },
	'tag' => { 'pagenum' => sub { print "PageXofY"; }, },
	));

	$self->SUPER::_format($node);
}

#----------------------------------------------------------------------
# Format an LI (list item) node (part of BIG UGLY HACK to get spacing
# right in MS Word) (private instance method)

sub _format_LI
{
	my ($self, $node) = @_;
	my $checkp = 1;

	print $self->_recode($node);
	foreach (@{$node->{'content'} || []})
	{
		my $inxt = $_->{'next'};		# Next in item
		my $lnxt = $_->{'parent'}{'next'};	# Next in list

		while ($inxt &&
		  ($inxt->{'type'} ne 'b-tag' ||
		  $inxt->{'tag'} =~ /^(?:b|em|i)$/))
		{
			$inxt = $inxt->{'next'};
		}

		while ($lnxt &&
		  $lnxt->{'type'} =~ /^(?:comment|space)$/)
		{
			$lnxt = $lnxt->{'next'};
		}

		#
		# Insert a paragraph tag if there is more content
		# in this item or if there is another item in the
		# list. The "LI P" selector in the style sheet will
		# suppress spacing for this code.
		#
		print "<P>" if ($checkp &&
		  ($inxt || ($lnxt->{'type'} eq 'b-tag' && 
		  $lnxt->{'tag'} eq 'li')));

		$self->_format($_);
		$checkp = ($_->{'type'} eq 'b-tag' &&
		  $_->{'tag'} !~ /^(?:b|em|i)$/);
	}
}

#----------------------------------------------------------------------
# Create a new renderer (public class method)

sub new
{
	my ($class) = @_;
	my $self = $class->SUPER::new();

	bless $self, $class;
	$self->{'table_spacer'} = "<BR>\n";

	return $self;
}

#----------------------------------------------------------------------
# Generate the HTML HEAD section (private instance method)

sub _render_head
{
	my ($self) = @_;

	return if ($self->{'did_head'});

	print <<EOT;
<HTML>
<HEAD>
<TITLE>$self->{'title'}</TITLE>
<STYLE>
BODY {
	font-size: 10pt;
}
H1 {
	color: #000099;
	font-size: 16pt;
	text-decoration: underline;
}
TABLE H2 {
	color: #000099;
	font-size: 14pt;
	margin-bottom: 0;
}
H2 {
	color: #000099;
	font-size: 14pt;
}
TABLE H3 {
	font-size: 12pt;
	margin-bottom: 0;
}
H3 {
	font-size: 12pt;
}
/* Lot's of hacks to fix spacing!! */
LI {
	margin-top: 0px;
}
LI LI {
	margin-bottom: 0px;
}
LI P {
	margin-bottom: 0px;
	margin-top: 0px;
}
TABLE LI {
	margin-bottom: 0px;
}
STRONG {
	font-weight: bold;
	text-decoration: underline;
}
</STYLE>
</HEAD>
<BODY bgcolor='#FFFFFF'>
EOT

	++$self->{'did_head'};
}

1;
